#/usr/bin/env python

import numpy

from osgeo import gdal

testfile = 'test.tiff'

def _load(filename):
    # @NOTE: the short version give me a SEGFAULT!
    #   data = gdal.Open(filename).GetRasterBand(1).ReadAsArray()
    dataset = gdal.Open(filename)
    band = dataset.GetRasterBand(1)
    return band.ReadAsArray()

def test_real():
    origData = _load(testfile)
    data = _load('real.tiff')
    return numpy.alltrue(data == origData.real)

def test_imag():
    origData = _load(testfile)
    data = _load('imag.tiff')
    return numpy.alltrue(data == origData.imag)

def test_mag():
    origData = _load(testfile)
    data = _load('mag.tiff')
    return numpy.alltrue(data == abs(origData))

def test_phase():
    origData = _load(testfile)
    data = _load('phase.tiff')
    return numpy.allclose(data, numpy.angle(origData))

def test_sum():
    origData = _load(testfile)
    data = _load('sum.tiff')
    return numpy.alltrue(data == (origData.real + origData.imag))

def test_diff():
    origData = _load(testfile)
    data = _load('diff.tiff')
    return numpy.alltrue(data == (origData.real - origData.imag))

def main():
    print 'test real: %s' % (test_real() and 'OK' or 'ERROR')
    print 'test imag: %s' % (test_imag() and 'OK' or 'ERROR')
    print 'test magnitude: %s' % (test_mag() and 'OK' or 'ERROR')
    print 'test phase: %s' % (test_phase() and 'OK' or 'ERROR')
    print 'test sum: %s' % (test_sum() and 'OK' or 'ERROR')
    print 'test diff: %s' % (test_diff() and 'OK' or 'ERROR')

if __name__ == '__main__':
    main()
